@@ -1,9 +1,9 @@
 package BorderStyle::ASCII::SingleLineOuterOnly;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-31'; # DATE
+our $DATE = '2021-02-19'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -36,10 +36,63 @@ BorderStyle::ASCII::SingleLineOuterOnly - Single line border with ASCII characte
 
 =head1 VERSION
 
-This document describes version 0.005 of BorderStyle::ASCII::SingleLineOuterOnly (from Perl distribution BorderStyles-Standard), released on 2021-01-31.
+This document describes version 0.006 of BorderStyle::ASCII::SingleLineOuterOnly (from Perl distribution BorderStyles-Standard), released on 2021-02-19.
 
 =head1 SYNOPSIS
 
+To use with L<Text::ANSITable>:
+
+ use Text::ANSITable;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ my $t = Text::ANSITable->new;
+ $t->border_style("ASCII::SingleLineOuterOnly");
+ $t->columns($rows->[0]);
+ $t->add_row($rows->[$_]) for 1 .. $#{ $rows };
+ print $t->draw;
+
+
+Sample output:
+
+ .----------------------------------------.
+ | ColumName1   ColumnNameB   ColumnNameC |
+ |                                        |
+ | row1A        row1B         row1C       |
+ | row2A        row2B         row2C       |
+ | row3A        row3B         row3C       |
+ `----------------------------------------'
+
+To use with L<Text::Table::Span>:
+
+ use Text::Table::Span qw/generate_table/;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"ASCII::SingleLineOuterOnly");
+
+
+Sample output:
+
+ .----------------------------------------.
+   ColumName1   ColumnNameB   ColumnNameC |
+ |                                        |
+   row1A        row1B         row1C       |
+ +----------------------------------------+
+   row2A        row2B         row2C       |
+ +----------------------------------------+
+   row3A        row3B         row3C       |
+ `----------------------------------------'
+ 
+
 To use with L<Text::Table::TinyBorderStyle>:
 
  use Text::Table::TinyBorderStyle qw/generate_table/;
@@ -52,6 +105,7 @@ To use with L<Text::Table::TinyBorderStyle>:
    ];
  generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BorderStyle::ASCII::SingleLineOuterOnly");
 
+
 Sample output:
 
  .----------------------------------------.
@@ -64,11 +118,6 @@ Sample output:
  | row3A        row3B         row3C       |
  `----------------------------------------'
 
-
-To use with L<Text::ANSITable>:
-
- # TODO
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/BorderStyles-Standard>.
